<?php
/**
 * light_roast functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Light_Roast
 */

if ( ! function_exists( 'light_roast_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function light_roast_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on light_roast, use a find and replace
	 * to change 'light_roast' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'light-roast', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'light-roast' ),
		'secondary' => esc_html__( 'Secondary', 'light-roast' ),
		'tertiary' => esc_html__( 'Tertiary', 'light-roast' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

}
endif;
add_action( 'after_setup_theme', 'light_roast_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function light_roast_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'light_roast_content_width', 640 );
}
add_action( 'after_setup_theme', 'light_roast_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function light_roast_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'light-roast' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'light_roast_widgets_init' );

function light_roast_add_google_fonts() {
	wp_enqueue_style( 'light-roast-google-fonts', 
	'http://fonts.googleapis.com/css?family=Josefin+Sans:300,400,600,700|Merriweather', 
	false );
}



add_action( 'wp_enqueue_scripts', 'light_roast_add_google_fonts' );

/**
 * Enqueue scripts and styles.
 */
function light_roast_scripts() {


	wp_enqueue_style ("font-awesome", get_template_directory_uri() . '/fonts/font-awesome/css/font-awesome.min.css', array(), '20160805');

	if (get_theme_mod ('old_layout') == "") {
		wp_enqueue_style( 'light-roast-style', get_stylesheet_uri() );

		if( get_theme_mod( 'layout_select' ) == 'sidebar-content' ) {
			wp_enqueue_style('light-roast-sidebar-content', get_template_directory_uri() . '/css/sidebar-content.css', array(), '20160204' );
		}
	
		if( get_theme_mod( 'layout_select' ) == 'content-sidebar' ) {
			wp_enqueue_style('light-roast-content-sidebar', get_template_directory_uri() . '/css/content-sidebar.css', array(), '2016020402' );
		}	
	}

	else {
		wp_enqueue_style( 'light-roast-style', get_template_directory_uri() . '/css/style-old.css', array(), '20160204' );

		if( get_theme_mod( 'layout_select' ) == 'sidebar-content' ) {
			wp_enqueue_style('light-roast-sidebar-content', get_template_directory_uri() . '/css/sidebar-content-old.css', array(), '20160204' );
		}
	
		if( get_theme_mod( 'layout_select' ) == 'content-sidebar' ) {
			wp_enqueue_style('light-roast-content-sidebar', get_template_directory_uri() . '/css/content-sidebar-old.css', array(), '2016020402' );
		}	
	}

	if (get_theme_mod ('hide_homepage') == "") {
			wp_enqueue_style('light-roast-no-sidebar-front-page', get_template_directory_uri() . '/css/no-sidebar-front-page.css', array(), '2016020402' );
	}
	wp_enqueue_script ( 'light-roast-navbar', get_template_directory_uri() . '/js/navbar-script.js', array( 'jquery'), '2016020403' );
	
	wp_enqueue_script( 'light-roast-slider', get_template_directory_uri() . '/js/slider-script.js', array( 'jquery'), '20160205', true );
	
	wp_enqueue_script( 'light-roast-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'light-roast-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'light_roast_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/* Theme Options */

/*Adds individual sections, settings, and controls to the theme customizer */

function light_roast_customizer( $wp_customize ) {


	
	/* Layout Options */
	$wp_customize->add_section(
		'layout_options',
		array(
			'title' => esc_html__('Layout Options', 'light-roast'),
			'description' => esc_html__('Change the layout orientation.', 'light-roast'),
			'priority' => 34,
		)
	);
	$wp_customize->add_setting(
		'layout_select',
		array(
			'default' => 'content-sidebar',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
	'layout_select',
		array (
			'label' => 'Layouts',
			'section' => 'layout_options',
			'type' => 'select',
			'choices' => array(
				'no-sidebar' => esc_html__('No Sidebar', 'light-roast'),
				'content-sidebar' => esc_html__('Content-Sidebar', 'light-roast'),
				'sidebar-content' => esc_html__('Sidebar-Content', 'light-roast'),
			),
		)
	);
	$wp_customize->add_setting(
		'hide_on_home',
		array (
			'sanitize_callback' => 'light_roast_sanitize_checkbox'
		)
	);
	$wp_customize->add_control(
		'hide_on_home',
		array(
			'type' => 'checkbox',
			'label' => esc_html__('Hide sidebar on home page', 'light-roast'),
			'section' => 'layout_options',
		)
	);
	
	/* Footer Options */
	$wp_customize->add_section(
		'footer-options',
		array(
		'title' => esc_html__('Footer Options', 'light-roast'),
		'description' => esc_html__('Options for your footer.', 'light-roast'),
		'priority' => 35,
		)
	);
	$wp_customize->add_setting(
		'copyright_textbox',
		array(
			'default' => esc_html__(get_bloginfo(name), 'light-roast'),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		'copyright_textbox',
		array(
			'label' => esc_html__('Copyright text:', 'light-roast'),
			'section' => 'footer-options',
			'type'=>'text',
		)
	);

	$wp_customize->add_setting(
		'hide_copyright',
		array (
			'sanitize_callback' => 'light_roast_sanitize_checkbox'
		)
	);
	$wp_customize->add_control(
		'hide_copyright',
		array(
			'type' => 'checkbox',
			'label' => esc_html__('Hide copyright text', 'light-roast'),
			'section' => 'footer-options',
		)
	);

	/* Old CSS */
	$wp_customize->add_section(
		'old-layout',
		array(
		'title' => esc_html__('Old Design', 'light-roast'),
		'description' => esc_html__('Option to revert to the old Light Roast design.', 'light-roast'),
		'priority' => 999,
		)
	);

	$wp_customize->add_setting(
		'old_layout',
		array (
			'sanitize_callback' => 'light_roast_sanitize_checkbox'
		)
	);
	$wp_customize->add_control(
		'old_layout',
		array(
			'type' => 'checkbox',
			'label' => esc_html__('Revert to the old Light Roast design', 'light-roast'),
			'section' => 'old-layout',
		)
	);

}

add_action( 'customize_register', 'light_roast_customizer');


function light_roast_sanitize_checkbox ( $input ) {
	if ( $input == 1 ) {
		return 1;
	}
		else {
		return '';
	}
}